@@ -25,11 +25,11 @@ Template::Flute - Modern designer-friendly HTML templating Engine
 
 =head1 VERSION
 
-Version 0.020
+Version 0.021
 
 =cut
 
-our $VERSION = '0.020';
+our $VERSION = '0.021';
 
 =head1 SYNOPSIS
 
@@ -960,7 +960,7 @@ sub _sub_process {
             }
 
 			# Increment count
-			$spec_class->{increment} = new Template::Flute::Increment(
+			$spec_class->{increment} = Template::Flute::Increment->new(
 				increment => $spec_class->{increment}->{increment},
 				start => $count
 			) if $spec_class->{increment};
