@@ -3,6 +3,7 @@ package Template::Flute::Expression;
 use strict;
 use warnings;
 
+use base 'Template::Flute';
 use Scalar::Util qw/reftype/;
 
 =head1 NAME
@@ -186,6 +187,8 @@ sub _value {
 	&& defined($values_ref->{$name})
 	&& $values_ref->{$name} =~ /\S/) {
 	$value = $values_ref->{$name};
+    } elsif ($self->_is_record_object($values_ref) && $values_ref->can($name)) {
+        $value = $values_ref->$name;
     }
     else {
 	$value = '';
